package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.KaoqinRecord;

/**
 * 考勤记录Mapper接口
 * 
 * @author ruoyi
 * @date 2023-02-02
 */
public interface KaoqinRecordMapper 
{
    /**
     * 查询考勤记录
     * 
     * @param recordId 考勤记录主键
     * @return 考勤记录
     */
    public KaoqinRecord selectKaoqinRecordByRecordId(Long recordId);

    /**
     * 查询考勤记录列表
     * 
     * @param kaoqinRecord 考勤记录
     * @return 考勤记录集合
     */
    public List<KaoqinRecord> selectKaoqinRecordList(KaoqinRecord kaoqinRecord);

    /**
     * 新增考勤记录
     * 
     * @param kaoqinRecord 考勤记录
     * @return 结果
     */
    public int insertKaoqinRecord(KaoqinRecord kaoqinRecord);

    /**
     * 修改考勤记录
     * 
     * @param kaoqinRecord 考勤记录
     * @return 结果
     */
    public int updateKaoqinRecord(KaoqinRecord kaoqinRecord);

    /**
     * 删除考勤记录
     * 
     * @param recordId 考勤记录主键
     * @return 结果
     */
    public int deleteKaoqinRecordByRecordId(Long recordId);

    /**
     * 批量删除考勤记录
     * 
     * @param recordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKaoqinRecordByRecordIds(Long[] recordIds);
}
